StrMath

Struct StrMath 

pub struct StrMath<'a> { /* private fields */ }
The main type that implements mathematical operations for strings.

Implementations

Source

impl StrMath<'static>

pub const fn new() -> Self

Creates a new StrMath with an empty string slice.

Source

impl<'a> StrMath<'a>

pub const fn new_slice(s: &'a str) -> Self

Constructs a new StrMath with a string slice.

pub const fn new_owned(s: String) -> Self

Constructs a new StrMath with an owned string value.

pub fn into_owned(inst: Self) -> Self

Convert this StrMath into another StrMath with owned value.

Note: this is an associated function, which means that you have to call it as StrMath::into_owned(s) instead of s.into_owned(). This is so that there is no conflict with a method on the inner type.

Methods from Deref<Target = Cow<'a, str>>

1.0.0 · Source

pub fn to_mut(&mut self) -> &mut <B as ToOwned>::Owned

Acquires a mutable reference to the owned form of the data.

Clones the data if it is not already owned.

Examples
use std::borrow::Cow;

let mut cow = Cow::Borrowed("foo");
cow.to_mut().make_ascii_uppercase();

assert_eq!(
  cow,
  Cow::Owned(String::from("FOO")) as Cow<'_, str>
);